<p>{{ proposal.speaker.name }} attached you as an additional speaker to a
    talk proposal for {{ current_site.name }} entitled "{{ proposal.title }}".</p>

<p>For more details, visit the {{ current_site.name }} speaker dashboard:
    <a href="http://{{ current_site }}{% url dashboard %}">http://{{ current_site }}{% url dashboard %}</a>
</p>
