{% extends "site_base.html" %}

{% load sitetree %}
{% load i18n %}

{% block body_class %}cms-page{% endblock %}

{% block head_title %}{{ page.title }}{% endblock %}

{% block breadcrumbs %}{% sitetree_breadcrumbs from "main" %}{% endblock %}

{% block body %}
    {% if editable %}
        <div class="pull-right">
            <a href="{% url cms_page_edit page.path %}" class="btn"><i class="icon-pencil icon-large"></i> Edit this page</a>
        </div>
    {% endif %}
    <h2>{{ page.title }}</h2>
    
    <div class="page-content">
        {{ page.body }}
    </div>
    
{% endblock %}