{% load sponsorship_tags %}
{% sponsor_levels as levels %}
<div class="sponsor-list">
{% for level in levels %}
    <h3>{{ level.name }}</h3>
    
    {% for sponsor in level.sponsors %}
        {% include "sponsorship/_sponsor_link.html" with sponsor=sponsor %}
    {% endfor %}
{% endfor %}
</div>
